@@ -1,10 +1,4 @@
-import sys
-from typing import Any
-
-if sys.version_info < (3, 8):
-    from typing_extensions import Protocol  # pragma: no cover
-else:
-    from typing import Protocol  # pragma: no cover
+from typing import Protocol
 
 from fastapi import Response
 from fastapi.security.base import SecurityBase
@@ -19,11 +13,9 @@ class TransportLogoutNotSupportedError(Exception):
 class Transport(Protocol):
     scheme: SecurityBase
 
-    async def get_login_response(self, token: str, response: Response) -> Any:
-        ...  # pragma: no cover
+    async def get_login_response(self, token: str) -> Response: ...  # pragma: no cover
 
-    async def get_logout_response(self, response: Response) -> Any:
-        ...  # pragma: no cover
+    async def get_logout_response(self) -> Response: ...  # pragma: no cover
 
     @staticmethod
     def get_openapi_login_responses_success() -> OpenAPIResponseType:
