@@ -1,10 +1,4 @@
-import sys
-from typing import Generic, List, Optional, TypeVar
-
-if sys.version_info < (3, 8):
-    from typing_extensions import Protocol  # pragma: no cover
-else:
-    from typing import Protocol  # pragma: no cover
+from typing import Generic, Protocol, TypeVar
 
 ID = TypeVar("ID")
 
@@ -19,9 +13,6 @@ class UserProtocol(Protocol[ID]):
     is_superuser: bool
     is_verified: bool
 
-    def __init__(self, *args, **kwargs) -> None:
-        ...  # pragma: no cover
-
 
 class OAuthAccountProtocol(Protocol[ID]):
     """OAuth account protocol that ORM model should follow."""
@@ -29,14 +20,11 @@ class OAuthAccountProtocol(Protocol[ID]):
     id: ID
     oauth_name: str
     access_token: str
-    expires_at: Optional[int]
-    refresh_token: Optional[str]
+    expires_at: int | None
+    refresh_token: str | None
     account_id: str
     account_email: str
 
-    def __init__(self, *args, **kwargs) -> None:
-        ...  # pragma: no cover
-
 
 UP = TypeVar("UP", bound=UserProtocol)
 OAP = TypeVar("OAP", bound=OAuthAccountProtocol)
@@ -45,7 +33,13 @@ OAP = TypeVar("OAP", bound=OAuthAccountProtocol)
 class UserOAuthProtocol(UserProtocol[ID], Generic[ID, OAP]):
     """User protocol including a list of OAuth accounts."""
 
-    oauth_accounts: List[OAP]
+    id: ID
+    email: str
+    hashed_password: str
+    is_active: bool
+    is_superuser: bool
+    is_verified: bool
+    oauth_accounts: list[OAP]
 
 
 UOAP = TypeVar("UOAP", bound=UserOAuthProtocol)
