@@ -1,11 +1,10 @@
 from enum import Enum
-from typing import Dict, Union
 
 from pydantic import BaseModel
 
 
 class ErrorModel(BaseModel):
-    detail: Union[str, Dict[str, str]]
+    detail: str | dict[str, str]
 
 
 class ErrorCodeReasonModel(BaseModel):
