@@ -1,17 +1,8 @@
 import asyncio
 import dataclasses
 import uuid
-from typing import (
-    Any,
-    AsyncGenerator,
-    Callable,
-    Dict,
-    Generic,
-    List,
-    Optional,
-    Type,
-    Union,
-)
+from collections.abc import AsyncGenerator, Callable
+from typing import Any, Generic
 from unittest.mock import MagicMock
 
 import httpx
@@ -39,18 +30,18 @@ lancelot_password_hash = password_helper.hash("lancelot")
 excalibur_password_hash = password_helper.hash("excalibur")
 
 
-IDType = uuid.UUID
+IDType = UUID4
 
 
 @dataclasses.dataclass
 class UserModel(models.UserProtocol[IDType]):
     email: str
     hashed_password: str
-    id: uuid.UUID = dataclasses.field(default_factory=uuid.uuid4)
+    id: IDType = dataclasses.field(default_factory=uuid.uuid4)
     is_active: bool = True
     is_superuser: bool = False
     is_verified: bool = False
-    first_name: Optional[str] = None
+    first_name: str | None = None
 
 
 @dataclasses.dataclass
@@ -59,26 +50,26 @@ class OAuthAccountModel(models.OAuthAccountProtocol[IDType]):
     access_token: str
     account_id: str
     account_email: str
-    id: uuid.UUID = dataclasses.field(default_factory=uuid.uuid4)
-    expires_at: Optional[int] = None
-    refresh_token: Optional[str] = None
+    id: IDType = dataclasses.field(default_factory=uuid.uuid4)
+    expires_at: int | None = None
+    refresh_token: str | None = None
 
 
 @dataclasses.dataclass
 class UserOAuthModel(UserModel):
-    oauth_accounts: List[OAuthAccountModel] = dataclasses.field(default_factory=list)
+    oauth_accounts: list[OAuthAccountModel] = dataclasses.field(default_factory=list)
 
 
 class User(schemas.BaseUser[IDType]):
-    first_name: Optional[str]
+    first_name: str | None = None
 
 
 class UserCreate(schemas.BaseUserCreate):
-    first_name: Optional[str]
+    first_name: str | None = None
 
 
 class UserUpdate(schemas.BaseUserUpdate):
-    first_name: Optional[str]
+    first_name: str | None = None
 
 
 class UserOAuth(User, schemas.BaseOAuthAccountMixin):
@@ -92,7 +83,7 @@ class BaseTestUserManager(
     verification_token_secret = "SECRET"
 
     async def validate_password(
-        self, password: str, user: Union[schemas.UC, models.UP]
+        self, password: str, user: schemas.UC | models.UP
     ) -> None:
         if len(password) < 3:
             raise exceptions.InvalidPasswordException(
@@ -126,13 +117,6 @@ class UserManagerMock(BaseTestUserManager[models.UP]):
     _update: MagicMock
 
 
-@pytest.fixture(scope="session")
-def event_loop():
-    """Force the pytest-asyncio loop to be the main one."""
-    loop = asyncio.get_event_loop()
-    yield loop
-
-
 AsyncMethodMocker = Callable[..., MagicMock]
 
 
@@ -324,7 +308,7 @@ def mock_user_db(
     verified_superuser: UserModel,
 ) -> BaseUserDatabase[UserModel, IDType]:
     class MockUserDatabase(BaseUserDatabase[UserModel, IDType]):
-        async def get(self, id: UUID4) -> Optional[UserModel]:
+        async def get(self, id: UUID4) -> UserModel | None:
             if id == user.id:
                 return user
             if id == verified_user.id:
@@ -337,7 +321,7 @@ def mock_user_db(
                 return verified_superuser
             return None
 
-        async def get_by_email(self, email: str) -> Optional[UserModel]:
+        async def get_by_email(self, email: str) -> UserModel | None:
             lower_email = email.lower()
             if lower_email == user.email.lower():
                 return user
@@ -351,11 +335,11 @@ def mock_user_db(
                 return verified_superuser
             return None
 
-        async def create(self, create_dict: Dict[str, Any]) -> UserModel:
+        async def create(self, create_dict: dict[str, Any]) -> UserModel:
             return UserModel(**create_dict)
 
         async def update(
-            self, user: UserModel, update_dict: Dict[str, Any]
+            self, user: UserModel, update_dict: dict[str, Any]
         ) -> UserModel:
             for field, value in update_dict.items():
                 setattr(user, field, value)
@@ -376,7 +360,7 @@ def mock_user_db_oauth(
     verified_superuser_oauth: UserOAuthModel,
 ) -> BaseUserDatabase[UserOAuthModel, IDType]:
     class MockUserDatabase(BaseUserDatabase[UserOAuthModel, IDType]):
-        async def get(self, id: UUID4) -> Optional[UserOAuthModel]:
+        async def get(self, id: UUID4) -> UserOAuthModel | None:
             if id == user_oauth.id:
                 return user_oauth
             if id == verified_user_oauth.id:
@@ -389,7 +373,7 @@ def mock_user_db_oauth(
                 return verified_superuser_oauth
             return None
 
-        async def get_by_email(self, email: str) -> Optional[UserOAuthModel]:
+        async def get_by_email(self, email: str) -> UserOAuthModel | None:
             lower_email = email.lower()
             if lower_email == user_oauth.email.lower():
                 return user_oauth
@@ -405,7 +389,7 @@ def mock_user_db_oauth(
 
         async def get_by_oauth_account(
             self, oauth: str, account_id: str
-        ) -> Optional[UserOAuthModel]:
+        ) -> UserOAuthModel | None:
             user_oauth_account = user_oauth.oauth_accounts[0]
             if (
                 user_oauth_account.oauth_name == oauth
@@ -421,11 +405,11 @@ def mock_user_db_oauth(
                 return inactive_user_oauth
             return None
 
-        async def create(self, create_dict: Dict[str, Any]) -> UserOAuthModel:
+        async def create(self, create_dict: dict[str, Any]) -> UserOAuthModel:
             return UserOAuthModel(**create_dict)
 
         async def update(
-            self, user: UserOAuthModel, update_dict: Dict[str, Any]
+            self, user: UserOAuthModel, update_dict: dict[str, Any]
         ) -> UserOAuthModel:
             for field, value in update_dict.items():
                 setattr(user, field, value)
@@ -435,7 +419,7 @@ def mock_user_db_oauth(
             pass
 
         async def add_oauth_account(
-            self, user: UserOAuthModel, create_dict: Dict[str, Any]
+            self, user: UserOAuthModel, create_dict: dict[str, Any]
         ) -> UserOAuthModel:
             oauth_account = OAuthAccountModel(**create_dict)
             user.oauth_accounts.append(oauth_account)
@@ -445,7 +429,7 @@ def mock_user_db_oauth(
             self,
             user: UserOAuthModel,
             oauth_account: OAuthAccountModel,
-            update_dict: Dict[str, Any],
+            update_dict: dict[str, Any],
         ) -> UserOAuthModel:
             for field, value in update_dict.items():
                 setattr(oauth_account, field, value)
@@ -465,7 +449,7 @@ def mock_user_db_oauth(
 
 @pytest.fixture
 def make_user_manager(mocker: MockerFixture):
-    def _make_user_manager(user_manager_class: Type[BaseTestUserManager], mock_user_db):
+    def _make_user_manager(user_manager_class: type[BaseTestUserManager], mock_user_db):
         user_manager = user_manager_class(mock_user_db)
         mocker.spy(user_manager, "get_by_email")
         mocker.spy(user_manager, "request_verify")
@@ -517,8 +501,8 @@ class MockTransport(BearerTransport):
     def __init__(self, tokenUrl: str):
         super().__init__(tokenUrl)
 
-    async def get_logout_response(self, response: Response) -> Any:
-        return None
+    async def get_logout_response(self) -> Any:
+        return Response()
 
     @staticmethod
     def get_openapi_logout_responses_success() -> OpenAPIResponseType:
@@ -527,8 +511,8 @@ class MockTransport(BearerTransport):
 
 class MockStrategy(Strategy[UserModel, IDType]):
     async def read_token(
-        self, token: Optional[str], user_manager: BaseUserManager[UserModel, IDType]
-    ) -> Optional[UserModel]:
+        self, token: str | None, user_manager: BaseUserManager[UserModel, IDType]
+    ) -> UserModel | None:
         if token is not None:
             try:
                 parsed_id = user_manager.parse_id(token)
@@ -562,7 +546,7 @@ def get_test_client():
     async def _get_test_client(app: FastAPI) -> AsyncGenerator[httpx.AsyncClient, None]:
         async with LifespanManager(app):
             async with httpx.AsyncClient(
-                app=app, base_url="http://app.io"
+                transport=httpx.ASGITransport(app), base_url="http://app.io"
             ) as test_client:
                 yield test_client
 
