@@ -1,8 +1,8 @@
-from typing import Callable
+import uuid
+from collections.abc import Callable
 
 import pytest
 from fastapi.security import OAuth2PasswordRequestForm
-from pydantic import UUID4
 from pytest_mock import MockerFixture
 
 from fastapi_users.exceptions import (
@@ -63,9 +63,9 @@ def forgot_password_token(user_manager: UserManagerMock[UserModel]):
 
 
 @pytest.fixture
-def create_oauth2_password_request_form() -> (
-    Callable[[str, str], OAuth2PasswordRequestForm]
-):
+def create_oauth2_password_request_form() -> Callable[
+    [str, str], OAuth2PasswordRequestForm
+]:
     def _create_oauth2_password_request_form(username, password):
         return OAuth2PasswordRequestForm(username=username, password=password, scope="")
 
@@ -77,7 +77,7 @@ def create_oauth2_password_request_form() -> (
 class TestGet:
     async def test_not_existing_user(self, user_manager: UserManagerMock[UserModel]):
         with pytest.raises(UserNotExists):
-            await user_manager.get(UUID4("d35d213e-f3d8-4f08-954a-7e0d1bea286f"))
+            await user_manager.get(uuid.UUID("d35d213e-f3d8-4f08-954a-7e0d1bea286f"))
 
     async def test_existing_user(
         self, user_manager: UserManagerMock[UserModel], user: UserModel
@@ -139,7 +139,7 @@ class TestCreateUser:
     ):
         user = UserCreate(email=email, password="guinevere")
         created_user = await user_manager.create(user)
-        assert type(created_user) == UserModel
+        assert isinstance(created_user, UserModel)
 
         assert user_manager.on_after_register.called is True
 
@@ -151,7 +151,7 @@ class TestCreateUser:
             email="lancelot@camelot.b", password="guinevere", is_superuser=True
         )
         created_user = await user_manager.create(user, safe)
-        assert type(created_user) == UserModel
+        assert isinstance(created_user, UserModel)
         assert created_user.is_superuser is result
 
         assert user_manager.on_after_register.called is True
@@ -164,7 +164,7 @@ class TestCreateUser:
             email="lancelot@camelot.b", password="guinevere", is_active=False
         )
         created_user = await user_manager.create(user, safe)
-        assert type(created_user) == UserModel
+        assert isinstance(created_user, UserModel)
         assert created_user.is_active is result
 
         assert user_manager.on_after_register.called is True
@@ -585,6 +585,17 @@ class TestUpdateUser:
 
         assert user_manager.on_after_update.called is True
 
+    async def test_unsafe_update_password_unchanged(
+        self, user: UserModel, user_manager: UserManagerMock[UserModel]
+    ):
+        old_hashed_password = user.hashed_password
+        user_update = UserUpdate(password=None)
+        updated_user = await user_manager.update(user_update, user, safe=False)
+
+        assert updated_user.hashed_password == old_hashed_password
+
+        assert user_manager.on_after_update.called is True
+
     async def test_password_update_invalid(
         self, user: UserModel, user_manager: UserManagerMock[UserModel]
     ):
