@@ -1,7 +1,8 @@
-from typing import Any, Dict, cast
+from typing import Any, cast
 
 import httpx
 import pytest
+import pytest_asyncio
 from fastapi import FastAPI, status
 from httpx_oauth.oauth2 import BaseOAuth2, OAuth2
 
@@ -69,15 +70,13 @@ def test_app_requires_verification(app_factory):
     return app_factory(requires_verification=True)
 
 
-@pytest.fixture
-@pytest.mark.asyncio
+@pytest_asyncio.fixture
 async def test_app_client(test_app, get_test_client):
     async for client in get_test_client(test_app):
         yield client
 
 
-@pytest.fixture
-@pytest.mark.asyncio
+@pytest_asyncio.fixture
 async def test_app_client_redirect_url(test_app_redirect_url, get_test_client):
     async for client in get_test_client(test_app_redirect_url):
         yield client
@@ -185,7 +184,7 @@ class TestCallback:
 
         assert response.status_code == status.HTTP_400_BAD_REQUEST
 
-        data = cast(Dict[str, Any], response.json())
+        data = cast(dict[str, Any], response.json())
         assert data["detail"] == ErrorCode.OAUTH_USER_ALREADY_EXISTS
 
         assert user_manager_oauth.on_after_login.called is False
@@ -215,7 +214,7 @@ class TestCallback:
 
         assert response.status_code == status.HTTP_200_OK
 
-        data = cast(Dict[str, Any], response.json())
+        data = cast(dict[str, Any], response.json())
         assert data["access_token"] == str(user_oauth.id)
 
         assert user_manager_oauth.on_after_login.called is True
@@ -279,7 +278,7 @@ class TestCallback:
             "CODE", "http://www.tintagel.bt/callback", None
         )
 
-        data = cast(Dict[str, Any], response.json())
+        data = cast(dict[str, Any], response.json())
         assert data["access_token"] == str(user_oauth.id)
         assert user_manager_oauth.on_after_login.called is True
 
@@ -487,7 +486,7 @@ class TestAssociateCallback:
 
         assert response.status_code == status.HTTP_200_OK
 
-        data = cast(Dict[str, Any], response.json())
+        data = cast(dict[str, Any], response.json())
         assert data["id"] == str(user_oauth.id)
 
     async def test_redirect_url_router(
@@ -522,7 +521,7 @@ class TestAssociateCallback:
             "CODE", "http://www.tintagel.bt/callback", None
         )
 
-        data = cast(Dict[str, Any], response.json())
+        data = cast(dict[str, Any], response.json())
         assert data["id"] == str(user_oauth.id)
 
     async def test_not_available_email(
